---
title: Energy Management module
summary: Provides the main interface to the OpenWebNet energy management system.
---

The Energy Management module provides the main interface to the OpenWebNet energy management system.

::: pyown.items.energy.energy.WhatEnergy
options:
show_inheritance_diagram: true

::: pyown.items.energy.energy.DimensionEnergy
options:
show_inheritance_diagram: true

::: pyown.items.energy.energy.TypeEnergy

::: pyown.items.energy.energy.EnergyManagement
options:
show_inheritance_diagram: true

::: pyown.items.energy.stop_go.StopGoStatus

::: pyown.items.energy.stop_go.StopGo
options:
show_inheritance_diagram: true

